Module: DfpApi
- Defined in:
- lib/dfp_api.rb,
lib/dfp_api/utils.rb,
lib/dfp_api/errors.rb,
lib/dfp_api/version.rb,
lib/dfp_api/api_config.rb,
lib/dfp_api/utils_reporter.rb,
lib/dfp_api/dfp_api_datetime.rb,
lib/dfp_api/dfp_api_statement.rb,
lib/dfp_api/credential_handler.rb,
lib/dfp_api/pql_statement_utils.rb,
lib/dfp_api/v201705/team_service.rb,
lib/dfp_api/v201705/user_service.rb,
lib/dfp_api/v201708/team_service.rb,
lib/dfp_api/v201708/user_service.rb,
lib/dfp_api/v201711/team_service.rb,
lib/dfp_api/v201711/user_service.rb,
lib/dfp_api/v201802/team_service.rb,
lib/dfp_api/v201802/user_service.rb,
lib/dfp_api/v201705/label_service.rb,
lib/dfp_api/v201705/order_service.rb,
lib/dfp_api/v201708/label_service.rb,
lib/dfp_api/v201708/order_service.rb,
lib/dfp_api/v201711/label_service.rb,
lib/dfp_api/v201711/order_service.rb,
lib/dfp_api/v201802/label_service.rb,
lib/dfp_api/v201802/order_service.rb,
lib/dfp_api/v201705/report_service.rb,
lib/dfp_api/v201708/report_service.rb,
lib/dfp_api/v201711/report_service.rb,
lib/dfp_api/v201802/report_service.rb,
lib/dfp_api/v201705/ad_rule_service.rb,
lib/dfp_api/v201705/company_service.rb,
lib/dfp_api/v201705/contact_service.rb,
lib/dfp_api/v201705/content_service.rb,
lib/dfp_api/v201705/network_service.rb,
lib/dfp_api/v201705/package_service.rb,
lib/dfp_api/v201705/product_service.rb,
lib/dfp_api/v201708/ad_rule_service.rb,
lib/dfp_api/v201708/company_service.rb,
lib/dfp_api/v201708/contact_service.rb,
lib/dfp_api/v201708/content_service.rb,
lib/dfp_api/v201708/network_service.rb,
lib/dfp_api/v201708/package_service.rb,
lib/dfp_api/v201708/product_service.rb,
lib/dfp_api/v201711/ad_rule_service.rb,
lib/dfp_api/v201711/company_service.rb,
lib/dfp_api/v201711/contact_service.rb,
lib/dfp_api/v201711/content_service.rb,
lib/dfp_api/v201711/network_service.rb,
lib/dfp_api/v201711/package_service.rb,
lib/dfp_api/v201711/product_service.rb,
lib/dfp_api/v201802/ad_rule_service.rb,
lib/dfp_api/v201802/company_service.rb,
lib/dfp_api/v201802/contact_service.rb,
lib/dfp_api/v201802/content_service.rb,
lib/dfp_api/v201802/network_service.rb,
lib/dfp_api/v201802/package_service.rb,
lib/dfp_api/v201802/product_service.rb,
lib/dfp_api/v201705/activity_service.rb,
lib/dfp_api/v201705/creative_service.rb,
lib/dfp_api/v201705/forecast_service.rb,
lib/dfp_api/v201705/proposal_service.rb,
lib/dfp_api/v201708/activity_service.rb,
lib/dfp_api/v201708/creative_service.rb,
lib/dfp_api/v201708/forecast_service.rb,
lib/dfp_api/v201708/proposal_service.rb,
lib/dfp_api/v201711/activity_service.rb,
lib/dfp_api/v201711/creative_service.rb,
lib/dfp_api/v201711/forecast_service.rb,
lib/dfp_api/v201711/proposal_service.rb,
lib/dfp_api/v201802/activity_service.rb,
lib/dfp_api/v201802/creative_service.rb,
lib/dfp_api/v201802/forecast_service.rb,
lib/dfp_api/v201802/proposal_service.rb,
lib/dfp_api/v201705/base_rate_service.rb,
lib/dfp_api/v201705/inventory_service.rb,
lib/dfp_api/v201705/line_item_service.rb,
lib/dfp_api/v201705/placement_service.rb,
lib/dfp_api/v201705/rate_card_service.rb,
lib/dfp_api/v201708/base_rate_service.rb,
lib/dfp_api/v201708/inventory_service.rb,
lib/dfp_api/v201708/line_item_service.rb,
lib/dfp_api/v201708/placement_service.rb,
lib/dfp_api/v201708/rate_card_service.rb,
lib/dfp_api/v201711/base_rate_service.rb,
lib/dfp_api/v201711/inventory_service.rb,
lib/dfp_api/v201711/line_item_service.rb,
lib/dfp_api/v201711/placement_service.rb,
lib/dfp_api/v201711/rate_card_service.rb,
lib/dfp_api/v201802/base_rate_service.rb,
lib/dfp_api/v201802/inventory_service.rb,
lib/dfp_api/v201802/line_item_service.rb,
lib/dfp_api/v201802/placement_service.rb,
lib/dfp_api/v201802/rate_card_service.rb,
lib/dfp_api/v201705/creative_set_service.rb,
lib/dfp_api/v201705/custom_field_service.rb,
lib/dfp_api/v201705/native_style_service.rb,
lib/dfp_api/v201705/premium_rate_service.rb,
lib/dfp_api/v201708/creative_set_service.rb,
lib/dfp_api/v201708/custom_field_service.rb,
lib/dfp_api/v201708/native_style_service.rb,
lib/dfp_api/v201708/premium_rate_service.rb,
lib/dfp_api/v201711/creative_set_service.rb,
lib/dfp_api/v201711/custom_field_service.rb,
lib/dfp_api/v201711/native_style_service.rb,
lib/dfp_api/v201711/premium_rate_service.rb,
lib/dfp_api/v201802/creative_set_service.rb,
lib/dfp_api/v201802/custom_field_service.rb,
lib/dfp_api/v201802/native_style_service.rb,
lib/dfp_api/v201802/premium_rate_service.rb,
lib/dfp_api/v201705/exchange_rate_service.rb,
lib/dfp_api/v201705/team_service_registry.rb,
lib/dfp_api/v201705/user_service_registry.rb,
lib/dfp_api/v201708/exchange_rate_service.rb,
lib/dfp_api/v201708/team_service_registry.rb,
lib/dfp_api/v201708/user_service_registry.rb,
lib/dfp_api/v201711/exchange_rate_service.rb,
lib/dfp_api/v201711/team_service_registry.rb,
lib/dfp_api/v201711/user_service_registry.rb,
lib/dfp_api/v201802/exchange_rate_service.rb,
lib/dfp_api/v201802/team_service_registry.rb,
lib/dfp_api/v201802/user_service_registry.rb,
lib/dfp_api/v201705/activity_group_service.rb,
lib/dfp_api/v201705/content_bundle_service.rb,
lib/dfp_api/v201705/label_service_registry.rb,
lib/dfp_api/v201705/order_service_registry.rb,
lib/dfp_api/v201708/activity_group_service.rb,
lib/dfp_api/v201708/content_bundle_service.rb,
lib/dfp_api/v201708/label_service_registry.rb,
lib/dfp_api/v201708/order_service_registry.rb,
lib/dfp_api/v201711/activity_group_service.rb,
lib/dfp_api/v201711/content_bundle_service.rb,
lib/dfp_api/v201711/label_service_registry.rb,
lib/dfp_api/v201711/order_service_registry.rb,
lib/dfp_api/v201802/activity_group_service.rb,
lib/dfp_api/v201802/content_bundle_service.rb,
lib/dfp_api/v201802/label_service_registry.rb,
lib/dfp_api/v201802/order_service_registry.rb,
lib/dfp_api/v201705/product_package_service.rb,
lib/dfp_api/v201705/report_service_registry.rb,
lib/dfp_api/v201708/product_package_service.rb,
lib/dfp_api/v201708/report_service_registry.rb,
lib/dfp_api/v201711/product_package_service.rb,
lib/dfp_api/v201711/report_service_registry.rb,
lib/dfp_api/v201802/product_package_service.rb,
lib/dfp_api/v201802/report_service_registry.rb,
lib/dfp_api/v201705/ad_rule_service_registry.rb,
lib/dfp_api/v201705/audience_segment_service.rb,
lib/dfp_api/v201705/company_service_registry.rb,
lib/dfp_api/v201705/contact_service_registry.rb,
lib/dfp_api/v201705/content_service_registry.rb,
lib/dfp_api/v201705/creative_wrapper_service.rb,
lib/dfp_api/v201705/custom_targeting_service.rb,
lib/dfp_api/v201705/network_service_registry.rb,
lib/dfp_api/v201705/package_service_registry.rb,
lib/dfp_api/v201705/product_service_registry.rb,
lib/dfp_api/v201705/product_template_service.rb,
lib/dfp_api/v201705/workflow_request_service.rb,
lib/dfp_api/v201708/ad_rule_service_registry.rb,
lib/dfp_api/v201708/audience_segment_service.rb,
lib/dfp_api/v201708/company_service_registry.rb,
lib/dfp_api/v201708/contact_service_registry.rb,
lib/dfp_api/v201708/content_service_registry.rb,
lib/dfp_api/v201708/creative_wrapper_service.rb,
lib/dfp_api/v201708/custom_targeting_service.rb,
lib/dfp_api/v201708/network_service_registry.rb,
lib/dfp_api/v201708/package_service_registry.rb,
lib/dfp_api/v201708/product_service_registry.rb,
lib/dfp_api/v201708/product_template_service.rb,
lib/dfp_api/v201708/workflow_request_service.rb,
lib/dfp_api/v201711/ad_rule_service_registry.rb,
lib/dfp_api/v201711/audience_segment_service.rb,
lib/dfp_api/v201711/company_service_registry.rb,
lib/dfp_api/v201711/contact_service_registry.rb,
lib/dfp_api/v201711/content_service_registry.rb,
lib/dfp_api/v201711/creative_wrapper_service.rb,
lib/dfp_api/v201711/custom_targeting_service.rb,
lib/dfp_api/v201711/network_service_registry.rb,
lib/dfp_api/v201711/package_service_registry.rb,
lib/dfp_api/v201711/product_service_registry.rb,
lib/dfp_api/v201711/product_template_service.rb,
lib/dfp_api/v201711/workflow_request_service.rb,
lib/dfp_api/v201802/ad_rule_service_registry.rb,
lib/dfp_api/v201802/audience_segment_service.rb,
lib/dfp_api/v201802/company_service_registry.rb,
lib/dfp_api/v201802/contact_service_registry.rb,
lib/dfp_api/v201802/content_service_registry.rb,
lib/dfp_api/v201802/creative_wrapper_service.rb,
lib/dfp_api/v201802/custom_targeting_service.rb,
lib/dfp_api/v201802/network_service_registry.rb,
lib/dfp_api/v201802/package_service_registry.rb,
lib/dfp_api/v201802/product_service_registry.rb,
lib/dfp_api/v201802/product_template_service.rb,
lib/dfp_api/v201802/workflow_request_service.rb,
lib/dfp_api/v201705/activity_service_registry.rb,
lib/dfp_api/v201705/ad_exclusion_rule_service.rb,
lib/dfp_api/v201705/creative_service_registry.rb,
lib/dfp_api/v201705/creative_template_service.rb,
lib/dfp_api/v201705/forecast_service_registry.rb,
lib/dfp_api/v201705/live_stream_event_service.rb,
lib/dfp_api/v201705/proposal_service_registry.rb,
lib/dfp_api/v201705/suggested_ad_unit_service.rb,
lib/dfp_api/v201708/activity_service_registry.rb,
lib/dfp_api/v201708/ad_exclusion_rule_service.rb,
lib/dfp_api/v201708/creative_service_registry.rb,
lib/dfp_api/v201708/creative_template_service.rb,
lib/dfp_api/v201708/forecast_service_registry.rb,
lib/dfp_api/v201708/live_stream_event_service.rb,
lib/dfp_api/v201708/proposal_service_registry.rb,
lib/dfp_api/v201708/suggested_ad_unit_service.rb,
lib/dfp_api/v201711/activity_service_registry.rb,
lib/dfp_api/v201711/ad_exclusion_rule_service.rb,
lib/dfp_api/v201711/cdn_configuration_service.rb,
lib/dfp_api/v201711/creative_service_registry.rb,
lib/dfp_api/v201711/creative_template_service.rb,
lib/dfp_api/v201711/forecast_service_registry.rb,
lib/dfp_api/v201711/live_stream_event_service.rb,
lib/dfp_api/v201711/proposal_service_registry.rb,
lib/dfp_api/v201711/suggested_ad_unit_service.rb,
lib/dfp_api/v201802/activity_service_registry.rb,
lib/dfp_api/v201802/ad_exclusion_rule_service.rb,
lib/dfp_api/v201802/cdn_configuration_service.rb,
lib/dfp_api/v201802/creative_service_registry.rb,
lib/dfp_api/v201802/creative_template_service.rb,
lib/dfp_api/v201802/forecast_service_registry.rb,
lib/dfp_api/v201802/live_stream_event_service.rb,
lib/dfp_api/v201802/proposal_service_registry.rb,
lib/dfp_api/v201802/suggested_ad_unit_service.rb,
lib/dfp_api/v201705/base_rate_service_registry.rb,
lib/dfp_api/v201705/inventory_service_registry.rb,
lib/dfp_api/v201705/line_item_service_registry.rb,
lib/dfp_api/v201705/line_item_template_service.rb,
lib/dfp_api/v201705/mobile_application_service.rb,
lib/dfp_api/v201705/placement_service_registry.rb,
lib/dfp_api/v201705/proposal_line_item_service.rb,
lib/dfp_api/v201705/rate_card_service_registry.rb,
lib/dfp_api/v201708/base_rate_service_registry.rb,
lib/dfp_api/v201708/inventory_service_registry.rb,
lib/dfp_api/v201708/line_item_service_registry.rb,
lib/dfp_api/v201708/line_item_template_service.rb,
lib/dfp_api/v201708/mobile_application_service.rb,
lib/dfp_api/v201708/placement_service_registry.rb,
lib/dfp_api/v201708/proposal_line_item_service.rb,
lib/dfp_api/v201708/rate_card_service_registry.rb,
lib/dfp_api/v201711/base_rate_service_registry.rb,
lib/dfp_api/v201711/inventory_service_registry.rb,
lib/dfp_api/v201711/line_item_service_registry.rb,
lib/dfp_api/v201711/line_item_template_service.rb,
lib/dfp_api/v201711/mobile_application_service.rb,
lib/dfp_api/v201711/placement_service_registry.rb,
lib/dfp_api/v201711/proposal_line_item_service.rb,
lib/dfp_api/v201711/rate_card_service_registry.rb,
lib/dfp_api/v201802/base_rate_service_registry.rb,
lib/dfp_api/v201802/inventory_service_registry.rb,
lib/dfp_api/v201802/line_item_service_registry.rb,
lib/dfp_api/v201802/line_item_template_service.rb,
lib/dfp_api/v201802/mobile_application_service.rb,
lib/dfp_api/v201802/placement_service_registry.rb,
lib/dfp_api/v201802/proposal_line_item_service.rb,
lib/dfp_api/v201802/rate_card_service_registry.rb,
lib/dfp_api/v201705/product_package_item_service.rb,
lib/dfp_api/v201708/product_package_item_service.rb,
lib/dfp_api/v201711/product_package_item_service.rb,
lib/dfp_api/v201802/product_package_item_service.rb,
lib/dfp_api/v201705/creative_set_service_registry.rb,
lib/dfp_api/v201705/custom_field_service_registry.rb,
lib/dfp_api/v201705/native_style_service_registry.rb,
lib/dfp_api/v201705/premium_rate_service_registry.rb,
lib/dfp_api/v201705/reconciliation_report_service.rb,
lib/dfp_api/v201705/user_team_association_service.rb,
lib/dfp_api/v201708/creative_set_service_registry.rb,
lib/dfp_api/v201708/custom_field_service_registry.rb,
lib/dfp_api/v201708/native_style_service_registry.rb,
lib/dfp_api/v201708/premium_rate_service_registry.rb,
lib/dfp_api/v201708/reconciliation_report_service.rb,
lib/dfp_api/v201708/user_team_association_service.rb,
lib/dfp_api/v201711/creative_set_service_registry.rb,
lib/dfp_api/v201711/custom_field_service_registry.rb,
lib/dfp_api/v201711/native_style_service_registry.rb,
lib/dfp_api/v201711/premium_rate_service_registry.rb,
lib/dfp_api/v201711/reconciliation_report_service.rb,
lib/dfp_api/v201711/user_team_association_service.rb,
lib/dfp_api/v201802/creative_set_service_registry.rb,
lib/dfp_api/v201802/custom_field_service_registry.rb,
lib/dfp_api/v201802/native_style_service_registry.rb,
lib/dfp_api/v201802/premium_rate_service_registry.rb,
lib/dfp_api/v201802/reconciliation_report_service.rb,
lib/dfp_api/v201802/user_team_association_service.rb,
lib/dfp_api/v201705/exchange_rate_service_registry.rb,
lib/dfp_api/v201708/exchange_rate_service_registry.rb,
lib/dfp_api/v201711/exchange_rate_service_registry.rb,
lib/dfp_api/v201802/exchange_rate_service_registry.rb,
lib/dfp_api/v201705/activity_group_service_registry.rb,
lib/dfp_api/v201705/content_bundle_service_registry.rb,
lib/dfp_api/v201708/activity_group_service_registry.rb,
lib/dfp_api/v201708/content_bundle_service_registry.rb,
lib/dfp_api/v201711/activity_group_service_registry.rb,
lib/dfp_api/v201711/content_bundle_service_registry.rb,
lib/dfp_api/v201802/activity_group_service_registry.rb,
lib/dfp_api/v201802/content_bundle_service_registry.rb,
lib/dfp_api/v201705/product_package_service_registry.rb,
lib/dfp_api/v201705/publisher_query_language_service.rb,
lib/dfp_api/v201708/product_package_service_registry.rb,
lib/dfp_api/v201708/publisher_query_language_service.rb,
lib/dfp_api/v201711/product_package_service_registry.rb,
lib/dfp_api/v201711/publisher_query_language_service.rb,
lib/dfp_api/v201802/product_package_service_registry.rb,
lib/dfp_api/v201802/publisher_query_language_service.rb,
lib/dfp_api/v201705/audience_segment_service_registry.rb,
lib/dfp_api/v201705/creative_wrapper_service_registry.rb,
lib/dfp_api/v201705/custom_targeting_service_registry.rb,
lib/dfp_api/v201705/product_template_service_registry.rb,
lib/dfp_api/v201705/reconciliation_report_row_service.rb,
lib/dfp_api/v201705/workflow_request_service_registry.rb,
lib/dfp_api/v201708/audience_segment_service_registry.rb,
lib/dfp_api/v201708/creative_wrapper_service_registry.rb,
lib/dfp_api/v201708/custom_targeting_service_registry.rb,
lib/dfp_api/v201708/product_template_service_registry.rb,
lib/dfp_api/v201708/reconciliation_report_row_service.rb,
lib/dfp_api/v201708/workflow_request_service_registry.rb,
lib/dfp_api/v201711/audience_segment_service_registry.rb,
lib/dfp_api/v201711/creative_wrapper_service_registry.rb,
lib/dfp_api/v201711/custom_targeting_service_registry.rb,
lib/dfp_api/v201711/product_template_service_registry.rb,
lib/dfp_api/v201711/reconciliation_report_row_service.rb,
lib/dfp_api/v201711/workflow_request_service_registry.rb,
lib/dfp_api/v201802/audience_segment_service_registry.rb,
lib/dfp_api/v201802/creative_wrapper_service_registry.rb,
lib/dfp_api/v201802/custom_targeting_service_registry.rb,
lib/dfp_api/v201802/product_template_service_registry.rb,
lib/dfp_api/v201802/reconciliation_report_row_service.rb,
lib/dfp_api/v201802/workflow_request_service_registry.rb,
lib/dfp_api/v201705/ad_exclusion_rule_service_registry.rb,
lib/dfp_api/v201705/creative_template_service_registry.rb,
lib/dfp_api/v201705/live_stream_event_service_registry.rb,
lib/dfp_api/v201705/suggested_ad_unit_service_registry.rb,
lib/dfp_api/v201708/ad_exclusion_rule_service_registry.rb,
lib/dfp_api/v201708/creative_template_service_registry.rb,
lib/dfp_api/v201708/live_stream_event_service_registry.rb,
lib/dfp_api/v201708/suggested_ad_unit_service_registry.rb,
lib/dfp_api/v201711/ad_exclusion_rule_service_registry.rb,
lib/dfp_api/v201711/cdn_configuration_service_registry.rb,
lib/dfp_api/v201711/creative_template_service_registry.rb,
lib/dfp_api/v201711/live_stream_event_service_registry.rb,
lib/dfp_api/v201711/suggested_ad_unit_service_registry.rb,
lib/dfp_api/v201802/ad_exclusion_rule_service_registry.rb,
lib/dfp_api/v201802/cdn_configuration_service_registry.rb,
lib/dfp_api/v201802/creative_template_service_registry.rb,
lib/dfp_api/v201802/live_stream_event_service_registry.rb,
lib/dfp_api/v201802/suggested_ad_unit_service_registry.rb,
lib/dfp_api/v201705/line_item_template_service_registry.rb,
lib/dfp_api/v201705/mobile_application_service_registry.rb,
lib/dfp_api/v201705/proposal_line_item_service_registry.rb,
lib/dfp_api/v201705/reconciliation_order_report_service.rb,
lib/dfp_api/v201708/line_item_template_service_registry.rb,
lib/dfp_api/v201708/mobile_application_service_registry.rb,
lib/dfp_api/v201708/proposal_line_item_service_registry.rb,
lib/dfp_api/v201708/reconciliation_order_report_service.rb,
lib/dfp_api/v201711/line_item_template_service_registry.rb,
lib/dfp_api/v201711/mobile_application_service_registry.rb,
lib/dfp_api/v201711/proposal_line_item_service_registry.rb,
lib/dfp_api/v201711/reconciliation_order_report_service.rb,
lib/dfp_api/v201802/line_item_template_service_registry.rb,
lib/dfp_api/v201802/mobile_application_service_registry.rb,
lib/dfp_api/v201802/proposal_line_item_service_registry.rb,
lib/dfp_api/v201802/reconciliation_order_report_service.rb,
lib/dfp_api/v201705/product_package_item_service_registry.rb,
lib/dfp_api/v201708/product_package_item_service_registry.rb,
lib/dfp_api/v201711/product_package_item_service_registry.rb,
lib/dfp_api/v201802/product_package_item_service_registry.rb,
lib/dfp_api/v201705/content_metadata_key_hierarchy_service.rb,
lib/dfp_api/v201705/line_item_creative_association_service.rb,
lib/dfp_api/v201705/reconciliation_report_service_registry.rb,
lib/dfp_api/v201705/user_team_association_service_registry.rb,
lib/dfp_api/v201708/content_metadata_key_hierarchy_service.rb,
lib/dfp_api/v201708/line_item_creative_association_service.rb,
lib/dfp_api/v201708/reconciliation_report_service_registry.rb,
lib/dfp_api/v201708/user_team_association_service_registry.rb,
lib/dfp_api/v201711/content_metadata_key_hierarchy_service.rb,
lib/dfp_api/v201711/line_item_creative_association_service.rb,
lib/dfp_api/v201711/reconciliation_report_service_registry.rb,
lib/dfp_api/v201711/user_team_association_service_registry.rb,
lib/dfp_api/v201802/content_metadata_key_hierarchy_service.rb,
lib/dfp_api/v201802/line_item_creative_association_service.rb,
lib/dfp_api/v201802/reconciliation_report_service_registry.rb,
lib/dfp_api/v201802/user_team_association_service_registry.rb,
lib/dfp_api/v201705/reconciliation_line_item_report_service.rb,
lib/dfp_api/v201708/reconciliation_line_item_report_service.rb,
lib/dfp_api/v201711/reconciliation_line_item_report_service.rb,
lib/dfp_api/v201802/reconciliation_line_item_report_service.rb,
lib/dfp_api/v201705/publisher_query_language_service_registry.rb,
lib/dfp_api/v201708/publisher_query_language_service_registry.rb,
lib/dfp_api/v201711/publisher_query_language_service_registry.rb,
lib/dfp_api/v201802/publisher_query_language_service_registry.rb,
lib/dfp_api/v201705/reconciliation_report_row_service_registry.rb,
lib/dfp_api/v201708/reconciliation_report_row_service_registry.rb,
lib/dfp_api/v201711/reconciliation_report_row_service_registry.rb,
lib/dfp_api/v201802/reconciliation_report_row_service_registry.rb,
lib/dfp_api/v201705/reconciliation_order_report_service_registry.rb,
lib/dfp_api/v201708/reconciliation_order_report_service_registry.rb,
lib/dfp_api/v201711/reconciliation_order_report_service_registry.rb,
lib/dfp_api/v201802/reconciliation_order_report_service_registry.rb,
lib/dfp_api/v201705/content_metadata_key_hierarchy_service_registry.rb,
lib/dfp_api/v201705/line_item_creative_association_service_registry.rb,
lib/dfp_api/v201708/content_metadata_key_hierarchy_service_registry.rb,
lib/dfp_api/v201708/line_item_creative_association_service_registry.rb,
lib/dfp_api/v201711/content_metadata_key_hierarchy_service_registry.rb,
lib/dfp_api/v201711/line_item_creative_association_service_registry.rb,
lib/dfp_api/v201802/content_metadata_key_hierarchy_service_registry.rb,
lib/dfp_api/v201802/line_item_creative_association_service_registry.rb,
lib/dfp_api/v201705/reconciliation_line_item_report_service_registry.rb,
lib/dfp_api/v201708/reconciliation_line_item_report_service_registry.rb,
lib/dfp_api/v201711/reconciliation_line_item_report_service_registry.rb,
lib/dfp_api/v201802/reconciliation_line_item_report_service_registry.rb
Overview
- Copyright
Copyright 2014, Google Inc. All Rights Reserved.
- License
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
implied.
See the License for the specific language governing permissions and
limitations under the License.
FilterStatement object to allow for simpler query pagination logic.
Defined Under Namespace
Modules: ApiConfig, Errors, Utils, V201705, V201708, V201711, V201802 Classes: Api, CredentialHandler, DfpDate, DfpDateTime, FilterStatement, PQLQuery, PQLValues, StatementBuilder, UtilsReporter
Constant Summary collapse
- SUGGESTED_PAGE_LIMIT =
Default page size to use with the StatementBuilder.
500- LEGACY_DEFAULT_APPLICATION_NAME =
'dfp_ruby_examples'- DEFAULT_APPLICATION_NAME =
'INSERT_APPLICATION_NAME_HERE'