Module: DfpApiStatement

Defined in:
lib/dfp_api_statement.rb

Overview

Authors

[email protected] (Nicholas Chen)

Copyright

Copyright 2014, Google Inc. All Rights Reserved.

License

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied.
      See the License for the specific language governing permissions and
      limitations under the License.

FilterStatement object to allow for simpler query pagination logic.

Defined Under Namespace

Classes: FilterStatement

Constant Summary collapse

SUGGESTED_PAGE_LIMIT =
500