Module: DfpApi

Defined in:
lib/dfp_api.rb,
lib/dfp_api/errors.rb,
lib/dfp_api/version.rb,
lib/dfp_api/api_config.rb,
lib/dfp_api/dfp_api_statement.rb,
lib/dfp_api/credential_handler.rb,
lib/dfp_api/v201611/team_service.rb,
lib/dfp_api/v201611/user_service.rb,
lib/dfp_api/v201702/team_service.rb,
lib/dfp_api/v201702/user_service.rb,
lib/dfp_api/v201705/team_service.rb,
lib/dfp_api/v201705/user_service.rb,
lib/dfp_api/v201708/team_service.rb,
lib/dfp_api/v201708/user_service.rb,
lib/dfp_api/v201611/label_service.rb,
lib/dfp_api/v201611/order_service.rb,
lib/dfp_api/v201702/label_service.rb,
lib/dfp_api/v201702/order_service.rb,
lib/dfp_api/v201705/label_service.rb,
lib/dfp_api/v201705/order_service.rb,
lib/dfp_api/v201708/label_service.rb,
lib/dfp_api/v201708/order_service.rb,
lib/dfp_api/v201611/report_service.rb,
lib/dfp_api/v201702/report_service.rb,
lib/dfp_api/v201705/report_service.rb,
lib/dfp_api/v201708/report_service.rb,
lib/dfp_api/v201611/ad_rule_service.rb,
lib/dfp_api/v201611/company_service.rb,
lib/dfp_api/v201611/contact_service.rb,
lib/dfp_api/v201611/content_service.rb,
lib/dfp_api/v201611/network_service.rb,
lib/dfp_api/v201611/package_service.rb,
lib/dfp_api/v201611/product_service.rb,
lib/dfp_api/v201702/ad_rule_service.rb,
lib/dfp_api/v201702/company_service.rb,
lib/dfp_api/v201702/contact_service.rb,
lib/dfp_api/v201702/content_service.rb,
lib/dfp_api/v201702/network_service.rb,
lib/dfp_api/v201702/package_service.rb,
lib/dfp_api/v201702/product_service.rb,
lib/dfp_api/v201705/ad_rule_service.rb,
lib/dfp_api/v201705/company_service.rb,
lib/dfp_api/v201705/contact_service.rb,
lib/dfp_api/v201705/content_service.rb,
lib/dfp_api/v201705/network_service.rb,
lib/dfp_api/v201705/package_service.rb,
lib/dfp_api/v201705/product_service.rb,
lib/dfp_api/v201708/ad_rule_service.rb,
lib/dfp_api/v201708/company_service.rb,
lib/dfp_api/v201708/contact_service.rb,
lib/dfp_api/v201708/content_service.rb,
lib/dfp_api/v201708/network_service.rb,
lib/dfp_api/v201708/package_service.rb,
lib/dfp_api/v201708/product_service.rb,
lib/dfp_api/v201611/activity_service.rb,
lib/dfp_api/v201611/creative_service.rb,
lib/dfp_api/v201611/forecast_service.rb,
lib/dfp_api/v201611/proposal_service.rb,
lib/dfp_api/v201702/activity_service.rb,
lib/dfp_api/v201702/creative_service.rb,
lib/dfp_api/v201702/forecast_service.rb,
lib/dfp_api/v201702/proposal_service.rb,
lib/dfp_api/v201705/activity_service.rb,
lib/dfp_api/v201705/creative_service.rb,
lib/dfp_api/v201705/forecast_service.rb,
lib/dfp_api/v201705/proposal_service.rb,
lib/dfp_api/v201708/activity_service.rb,
lib/dfp_api/v201708/creative_service.rb,
lib/dfp_api/v201708/forecast_service.rb,
lib/dfp_api/v201708/proposal_service.rb,
lib/dfp_api/v201611/base_rate_service.rb,
lib/dfp_api/v201611/inventory_service.rb,
lib/dfp_api/v201611/line_item_service.rb,
lib/dfp_api/v201611/placement_service.rb,
lib/dfp_api/v201611/rate_card_service.rb,
lib/dfp_api/v201702/base_rate_service.rb,
lib/dfp_api/v201702/inventory_service.rb,
lib/dfp_api/v201702/line_item_service.rb,
lib/dfp_api/v201702/placement_service.rb,
lib/dfp_api/v201702/rate_card_service.rb,
lib/dfp_api/v201705/base_rate_service.rb,
lib/dfp_api/v201705/inventory_service.rb,
lib/dfp_api/v201705/line_item_service.rb,
lib/dfp_api/v201705/placement_service.rb,
lib/dfp_api/v201705/rate_card_service.rb,
lib/dfp_api/v201708/base_rate_service.rb,
lib/dfp_api/v201708/inventory_service.rb,
lib/dfp_api/v201708/line_item_service.rb,
lib/dfp_api/v201708/placement_service.rb,
lib/dfp_api/v201708/rate_card_service.rb,
lib/dfp_api/v201611/creative_set_service.rb,
lib/dfp_api/v201611/custom_field_service.rb,
lib/dfp_api/v201611/premium_rate_service.rb,
lib/dfp_api/v201702/creative_set_service.rb,
lib/dfp_api/v201702/custom_field_service.rb,
lib/dfp_api/v201702/native_style_service.rb,
lib/dfp_api/v201702/premium_rate_service.rb,
lib/dfp_api/v201705/creative_set_service.rb,
lib/dfp_api/v201705/custom_field_service.rb,
lib/dfp_api/v201705/native_style_service.rb,
lib/dfp_api/v201705/premium_rate_service.rb,
lib/dfp_api/v201708/creative_set_service.rb,
lib/dfp_api/v201708/custom_field_service.rb,
lib/dfp_api/v201708/native_style_service.rb,
lib/dfp_api/v201708/premium_rate_service.rb,
lib/dfp_api/v201611/exchange_rate_service.rb,
lib/dfp_api/v201611/team_service_registry.rb,
lib/dfp_api/v201611/user_service_registry.rb,
lib/dfp_api/v201702/exchange_rate_service.rb,
lib/dfp_api/v201702/team_service_registry.rb,
lib/dfp_api/v201702/user_service_registry.rb,
lib/dfp_api/v201705/exchange_rate_service.rb,
lib/dfp_api/v201705/team_service_registry.rb,
lib/dfp_api/v201705/user_service_registry.rb,
lib/dfp_api/v201708/exchange_rate_service.rb,
lib/dfp_api/v201708/team_service_registry.rb,
lib/dfp_api/v201708/user_service_registry.rb,
lib/dfp_api/v201611/activity_group_service.rb,
lib/dfp_api/v201611/content_bundle_service.rb,
lib/dfp_api/v201611/label_service_registry.rb,
lib/dfp_api/v201611/order_service_registry.rb,
lib/dfp_api/v201702/activity_group_service.rb,
lib/dfp_api/v201702/content_bundle_service.rb,
lib/dfp_api/v201702/label_service_registry.rb,
lib/dfp_api/v201702/order_service_registry.rb,
lib/dfp_api/v201705/activity_group_service.rb,
lib/dfp_api/v201705/content_bundle_service.rb,
lib/dfp_api/v201705/label_service_registry.rb,
lib/dfp_api/v201705/order_service_registry.rb,
lib/dfp_api/v201708/activity_group_service.rb,
lib/dfp_api/v201708/content_bundle_service.rb,
lib/dfp_api/v201708/label_service_registry.rb,
lib/dfp_api/v201708/order_service_registry.rb,
lib/dfp_api/v201611/product_package_service.rb,
lib/dfp_api/v201611/report_service_registry.rb,
lib/dfp_api/v201702/product_package_service.rb,
lib/dfp_api/v201702/report_service_registry.rb,
lib/dfp_api/v201705/product_package_service.rb,
lib/dfp_api/v201705/report_service_registry.rb,
lib/dfp_api/v201708/product_package_service.rb,
lib/dfp_api/v201708/report_service_registry.rb,
lib/dfp_api/v201611/ad_rule_service_registry.rb,
lib/dfp_api/v201611/audience_segment_service.rb,
lib/dfp_api/v201611/company_service_registry.rb,
lib/dfp_api/v201611/contact_service_registry.rb,
lib/dfp_api/v201611/content_service_registry.rb,
lib/dfp_api/v201611/creative_wrapper_service.rb,
lib/dfp_api/v201611/custom_targeting_service.rb,
lib/dfp_api/v201611/network_service_registry.rb,
lib/dfp_api/v201611/package_service_registry.rb,
lib/dfp_api/v201611/product_service_registry.rb,
lib/dfp_api/v201611/product_template_service.rb,
lib/dfp_api/v201611/workflow_request_service.rb,
lib/dfp_api/v201702/ad_rule_service_registry.rb,
lib/dfp_api/v201702/audience_segment_service.rb,
lib/dfp_api/v201702/company_service_registry.rb,
lib/dfp_api/v201702/contact_service_registry.rb,
lib/dfp_api/v201702/content_service_registry.rb,
lib/dfp_api/v201702/creative_wrapper_service.rb,
lib/dfp_api/v201702/custom_targeting_service.rb,
lib/dfp_api/v201702/network_service_registry.rb,
lib/dfp_api/v201702/package_service_registry.rb,
lib/dfp_api/v201702/product_service_registry.rb,
lib/dfp_api/v201702/product_template_service.rb,
lib/dfp_api/v201702/workflow_request_service.rb,
lib/dfp_api/v201705/ad_rule_service_registry.rb,
lib/dfp_api/v201705/audience_segment_service.rb,
lib/dfp_api/v201705/company_service_registry.rb,
lib/dfp_api/v201705/contact_service_registry.rb,
lib/dfp_api/v201705/content_service_registry.rb,
lib/dfp_api/v201705/creative_wrapper_service.rb,
lib/dfp_api/v201705/custom_targeting_service.rb,
lib/dfp_api/v201705/network_service_registry.rb,
lib/dfp_api/v201705/package_service_registry.rb,
lib/dfp_api/v201705/product_service_registry.rb,
lib/dfp_api/v201705/product_template_service.rb,
lib/dfp_api/v201705/workflow_request_service.rb,
lib/dfp_api/v201708/ad_rule_service_registry.rb,
lib/dfp_api/v201708/audience_segment_service.rb,
lib/dfp_api/v201708/company_service_registry.rb,
lib/dfp_api/v201708/contact_service_registry.rb,
lib/dfp_api/v201708/content_service_registry.rb,
lib/dfp_api/v201708/creative_wrapper_service.rb,
lib/dfp_api/v201708/custom_targeting_service.rb,
lib/dfp_api/v201708/network_service_registry.rb,
lib/dfp_api/v201708/package_service_registry.rb,
lib/dfp_api/v201708/product_service_registry.rb,
lib/dfp_api/v201708/product_template_service.rb,
lib/dfp_api/v201708/workflow_request_service.rb,
lib/dfp_api/v201611/activity_service_registry.rb,
lib/dfp_api/v201611/ad_exclusion_rule_service.rb,
lib/dfp_api/v201611/creative_service_registry.rb,
lib/dfp_api/v201611/creative_template_service.rb,
lib/dfp_api/v201611/forecast_service_registry.rb,
lib/dfp_api/v201611/live_stream_event_service.rb,
lib/dfp_api/v201611/proposal_service_registry.rb,
lib/dfp_api/v201611/suggested_ad_unit_service.rb,
lib/dfp_api/v201702/activity_service_registry.rb,
lib/dfp_api/v201702/ad_exclusion_rule_service.rb,
lib/dfp_api/v201702/creative_service_registry.rb,
lib/dfp_api/v201702/creative_template_service.rb,
lib/dfp_api/v201702/forecast_service_registry.rb,
lib/dfp_api/v201702/live_stream_event_service.rb,
lib/dfp_api/v201702/proposal_service_registry.rb,
lib/dfp_api/v201702/suggested_ad_unit_service.rb,
lib/dfp_api/v201705/activity_service_registry.rb,
lib/dfp_api/v201705/ad_exclusion_rule_service.rb,
lib/dfp_api/v201705/creative_service_registry.rb,
lib/dfp_api/v201705/creative_template_service.rb,
lib/dfp_api/v201705/forecast_service_registry.rb,
lib/dfp_api/v201705/live_stream_event_service.rb,
lib/dfp_api/v201705/proposal_service_registry.rb,
lib/dfp_api/v201705/suggested_ad_unit_service.rb,
lib/dfp_api/v201708/activity_service_registry.rb,
lib/dfp_api/v201708/ad_exclusion_rule_service.rb,
lib/dfp_api/v201708/creative_service_registry.rb,
lib/dfp_api/v201708/creative_template_service.rb,
lib/dfp_api/v201708/forecast_service_registry.rb,
lib/dfp_api/v201708/live_stream_event_service.rb,
lib/dfp_api/v201708/proposal_service_registry.rb,
lib/dfp_api/v201708/suggested_ad_unit_service.rb,
lib/dfp_api/v201611/base_rate_service_registry.rb,
lib/dfp_api/v201611/inventory_service_registry.rb,
lib/dfp_api/v201611/line_item_service_registry.rb,
lib/dfp_api/v201611/line_item_template_service.rb,
lib/dfp_api/v201611/mobile_application_service.rb,
lib/dfp_api/v201611/placement_service_registry.rb,
lib/dfp_api/v201611/proposal_line_item_service.rb,
lib/dfp_api/v201611/rate_card_service_registry.rb,
lib/dfp_api/v201702/base_rate_service_registry.rb,
lib/dfp_api/v201702/inventory_service_registry.rb,
lib/dfp_api/v201702/line_item_service_registry.rb,
lib/dfp_api/v201702/line_item_template_service.rb,
lib/dfp_api/v201702/mobile_application_service.rb,
lib/dfp_api/v201702/placement_service_registry.rb,
lib/dfp_api/v201702/proposal_line_item_service.rb,
lib/dfp_api/v201702/rate_card_service_registry.rb,
lib/dfp_api/v201705/base_rate_service_registry.rb,
lib/dfp_api/v201705/inventory_service_registry.rb,
lib/dfp_api/v201705/line_item_service_registry.rb,
lib/dfp_api/v201705/line_item_template_service.rb,
lib/dfp_api/v201705/mobile_application_service.rb,
lib/dfp_api/v201705/placement_service_registry.rb,
lib/dfp_api/v201705/proposal_line_item_service.rb,
lib/dfp_api/v201705/rate_card_service_registry.rb,
lib/dfp_api/v201708/base_rate_service_registry.rb,
lib/dfp_api/v201708/inventory_service_registry.rb,
lib/dfp_api/v201708/line_item_service_registry.rb,
lib/dfp_api/v201708/line_item_template_service.rb,
lib/dfp_api/v201708/mobile_application_service.rb,
lib/dfp_api/v201708/placement_service_registry.rb,
lib/dfp_api/v201708/proposal_line_item_service.rb,
lib/dfp_api/v201708/rate_card_service_registry.rb,
lib/dfp_api/v201611/product_package_item_service.rb,
lib/dfp_api/v201702/product_package_item_service.rb,
lib/dfp_api/v201705/product_package_item_service.rb,
lib/dfp_api/v201708/product_package_item_service.rb,
lib/dfp_api/v201611/creative_set_service_registry.rb,
lib/dfp_api/v201611/custom_field_service_registry.rb,
lib/dfp_api/v201611/premium_rate_service_registry.rb,
lib/dfp_api/v201611/reconciliation_report_service.rb,
lib/dfp_api/v201611/user_team_association_service.rb,
lib/dfp_api/v201702/creative_set_service_registry.rb,
lib/dfp_api/v201702/custom_field_service_registry.rb,
lib/dfp_api/v201702/native_style_service_registry.rb,
lib/dfp_api/v201702/premium_rate_service_registry.rb,
lib/dfp_api/v201702/reconciliation_report_service.rb,
lib/dfp_api/v201702/user_team_association_service.rb,
lib/dfp_api/v201705/creative_set_service_registry.rb,
lib/dfp_api/v201705/custom_field_service_registry.rb,
lib/dfp_api/v201705/native_style_service_registry.rb,
lib/dfp_api/v201705/premium_rate_service_registry.rb,
lib/dfp_api/v201705/reconciliation_report_service.rb,
lib/dfp_api/v201705/user_team_association_service.rb,
lib/dfp_api/v201708/creative_set_service_registry.rb,
lib/dfp_api/v201708/custom_field_service_registry.rb,
lib/dfp_api/v201708/native_style_service_registry.rb,
lib/dfp_api/v201708/premium_rate_service_registry.rb,
lib/dfp_api/v201708/reconciliation_report_service.rb,
lib/dfp_api/v201708/user_team_association_service.rb,
lib/dfp_api/v201611/exchange_rate_service_registry.rb,
lib/dfp_api/v201702/exchange_rate_service_registry.rb,
lib/dfp_api/v201705/exchange_rate_service_registry.rb,
lib/dfp_api/v201708/exchange_rate_service_registry.rb,
lib/dfp_api/v201611/activity_group_service_registry.rb,
lib/dfp_api/v201611/content_bundle_service_registry.rb,
lib/dfp_api/v201702/activity_group_service_registry.rb,
lib/dfp_api/v201702/content_bundle_service_registry.rb,
lib/dfp_api/v201705/activity_group_service_registry.rb,
lib/dfp_api/v201705/content_bundle_service_registry.rb,
lib/dfp_api/v201708/activity_group_service_registry.rb,
lib/dfp_api/v201708/content_bundle_service_registry.rb,
lib/dfp_api/v201611/product_package_service_registry.rb,
lib/dfp_api/v201611/publisher_query_language_service.rb,
lib/dfp_api/v201702/product_package_service_registry.rb,
lib/dfp_api/v201702/publisher_query_language_service.rb,
lib/dfp_api/v201705/product_package_service_registry.rb,
lib/dfp_api/v201705/publisher_query_language_service.rb,
lib/dfp_api/v201708/product_package_service_registry.rb,
lib/dfp_api/v201708/publisher_query_language_service.rb,
lib/dfp_api/v201611/audience_segment_service_registry.rb,
lib/dfp_api/v201611/creative_wrapper_service_registry.rb,
lib/dfp_api/v201611/custom_targeting_service_registry.rb,
lib/dfp_api/v201611/product_template_service_registry.rb,
lib/dfp_api/v201611/reconciliation_report_row_service.rb,
lib/dfp_api/v201611/workflow_request_service_registry.rb,
lib/dfp_api/v201702/audience_segment_service_registry.rb,
lib/dfp_api/v201702/creative_wrapper_service_registry.rb,
lib/dfp_api/v201702/custom_targeting_service_registry.rb,
lib/dfp_api/v201702/product_template_service_registry.rb,
lib/dfp_api/v201702/reconciliation_report_row_service.rb,
lib/dfp_api/v201702/workflow_request_service_registry.rb,
lib/dfp_api/v201705/audience_segment_service_registry.rb,
lib/dfp_api/v201705/creative_wrapper_service_registry.rb,
lib/dfp_api/v201705/custom_targeting_service_registry.rb,
lib/dfp_api/v201705/product_template_service_registry.rb,
lib/dfp_api/v201705/reconciliation_report_row_service.rb,
lib/dfp_api/v201705/workflow_request_service_registry.rb,
lib/dfp_api/v201708/audience_segment_service_registry.rb,
lib/dfp_api/v201708/creative_wrapper_service_registry.rb,
lib/dfp_api/v201708/custom_targeting_service_registry.rb,
lib/dfp_api/v201708/product_template_service_registry.rb,
lib/dfp_api/v201708/reconciliation_report_row_service.rb,
lib/dfp_api/v201708/workflow_request_service_registry.rb,
lib/dfp_api/v201611/ad_exclusion_rule_service_registry.rb,
lib/dfp_api/v201611/creative_template_service_registry.rb,
lib/dfp_api/v201611/live_stream_event_service_registry.rb,
lib/dfp_api/v201611/suggested_ad_unit_service_registry.rb,
lib/dfp_api/v201702/ad_exclusion_rule_service_registry.rb,
lib/dfp_api/v201702/creative_template_service_registry.rb,
lib/dfp_api/v201702/live_stream_event_service_registry.rb,
lib/dfp_api/v201702/suggested_ad_unit_service_registry.rb,
lib/dfp_api/v201705/ad_exclusion_rule_service_registry.rb,
lib/dfp_api/v201705/creative_template_service_registry.rb,
lib/dfp_api/v201705/live_stream_event_service_registry.rb,
lib/dfp_api/v201705/suggested_ad_unit_service_registry.rb,
lib/dfp_api/v201708/ad_exclusion_rule_service_registry.rb,
lib/dfp_api/v201708/creative_template_service_registry.rb,
lib/dfp_api/v201708/live_stream_event_service_registry.rb,
lib/dfp_api/v201708/suggested_ad_unit_service_registry.rb,
lib/dfp_api/v201611/line_item_template_service_registry.rb,
lib/dfp_api/v201611/mobile_application_service_registry.rb,
lib/dfp_api/v201611/proposal_line_item_service_registry.rb,
lib/dfp_api/v201611/reconciliation_order_report_service.rb,
lib/dfp_api/v201702/line_item_template_service_registry.rb,
lib/dfp_api/v201702/mobile_application_service_registry.rb,
lib/dfp_api/v201702/proposal_line_item_service_registry.rb,
lib/dfp_api/v201702/reconciliation_order_report_service.rb,
lib/dfp_api/v201705/line_item_template_service_registry.rb,
lib/dfp_api/v201705/mobile_application_service_registry.rb,
lib/dfp_api/v201705/proposal_line_item_service_registry.rb,
lib/dfp_api/v201705/reconciliation_order_report_service.rb,
lib/dfp_api/v201708/line_item_template_service_registry.rb,
lib/dfp_api/v201708/mobile_application_service_registry.rb,
lib/dfp_api/v201708/proposal_line_item_service_registry.rb,
lib/dfp_api/v201708/reconciliation_order_report_service.rb,
lib/dfp_api/v201611/product_package_item_service_registry.rb,
lib/dfp_api/v201702/product_package_item_service_registry.rb,
lib/dfp_api/v201705/product_package_item_service_registry.rb,
lib/dfp_api/v201708/product_package_item_service_registry.rb,
lib/dfp_api/v201611/content_metadata_key_hierarchy_service.rb,
lib/dfp_api/v201611/line_item_creative_association_service.rb,
lib/dfp_api/v201611/reconciliation_report_service_registry.rb,
lib/dfp_api/v201611/user_team_association_service_registry.rb,
lib/dfp_api/v201702/content_metadata_key_hierarchy_service.rb,
lib/dfp_api/v201702/line_item_creative_association_service.rb,
lib/dfp_api/v201702/reconciliation_report_service_registry.rb,
lib/dfp_api/v201702/user_team_association_service_registry.rb,
lib/dfp_api/v201705/content_metadata_key_hierarchy_service.rb,
lib/dfp_api/v201705/line_item_creative_association_service.rb,
lib/dfp_api/v201705/reconciliation_report_service_registry.rb,
lib/dfp_api/v201705/user_team_association_service_registry.rb,
lib/dfp_api/v201708/content_metadata_key_hierarchy_service.rb,
lib/dfp_api/v201708/line_item_creative_association_service.rb,
lib/dfp_api/v201708/reconciliation_report_service_registry.rb,
lib/dfp_api/v201708/user_team_association_service_registry.rb,
lib/dfp_api/v201611/reconciliation_line_item_report_service.rb,
lib/dfp_api/v201702/reconciliation_line_item_report_service.rb,
lib/dfp_api/v201705/reconciliation_line_item_report_service.rb,
lib/dfp_api/v201708/reconciliation_line_item_report_service.rb,
lib/dfp_api/v201611/publisher_query_language_service_registry.rb,
lib/dfp_api/v201702/publisher_query_language_service_registry.rb,
lib/dfp_api/v201705/publisher_query_language_service_registry.rb,
lib/dfp_api/v201708/publisher_query_language_service_registry.rb,
lib/dfp_api/v201611/reconciliation_report_row_service_registry.rb,
lib/dfp_api/v201702/reconciliation_report_row_service_registry.rb,
lib/dfp_api/v201705/reconciliation_report_row_service_registry.rb,
lib/dfp_api/v201708/reconciliation_report_row_service_registry.rb,
lib/dfp_api/v201611/reconciliation_order_report_service_registry.rb,
lib/dfp_api/v201702/reconciliation_order_report_service_registry.rb,
lib/dfp_api/v201705/reconciliation_order_report_service_registry.rb,
lib/dfp_api/v201708/reconciliation_order_report_service_registry.rb,
lib/dfp_api/v201611/content_metadata_key_hierarchy_service_registry.rb,
lib/dfp_api/v201611/line_item_creative_association_service_registry.rb,
lib/dfp_api/v201702/content_metadata_key_hierarchy_service_registry.rb,
lib/dfp_api/v201702/line_item_creative_association_service_registry.rb,
lib/dfp_api/v201705/content_metadata_key_hierarchy_service_registry.rb,
lib/dfp_api/v201705/line_item_creative_association_service_registry.rb,
lib/dfp_api/v201708/content_metadata_key_hierarchy_service_registry.rb,
lib/dfp_api/v201708/line_item_creative_association_service_registry.rb,
lib/dfp_api/v201611/reconciliation_line_item_report_service_registry.rb,
lib/dfp_api/v201702/reconciliation_line_item_report_service_registry.rb,
lib/dfp_api/v201705/reconciliation_line_item_report_service_registry.rb,
lib/dfp_api/v201708/reconciliation_line_item_report_service_registry.rb

Overview

Copyright

Copyright 2014, Google Inc. All Rights Reserved.

License

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied.
      See the License for the specific language governing permissions and
      limitations under the License.

FilterStatement object to allow for simpler query pagination logic.

Defined Under Namespace

Modules: ApiConfig, Errors, V201611, V201702, V201705, V201708 Classes: Api, CredentialHandler, FilterStatement

Constant Summary collapse

SUGGESTED_PAGE_LIMIT =

Default page size to use with the FilterStatement.

500
LEGACY_DEFAULT_APPLICATION_NAME =
'dfp_ruby_examples'
DEFAULT_APPLICATION_NAME =
'INSERT_APPLICATION_NAME_HERE'