Module: DfpApi

Defined in:
lib/dfp_api.rb,
lib/dfp_api/errors.rb,
lib/dfp_api/version.rb,
lib/dfp_api/api_config.rb,
lib/dfp_api/credential_handler.rb,
lib/dfp_api/v201208/team_service.rb,
lib/dfp_api/v201208/user_service.rb,
lib/dfp_api/v201211/team_service.rb,
lib/dfp_api/v201211/user_service.rb,
lib/dfp_api/v201302/team_service.rb,
lib/dfp_api/v201302/user_service.rb,
lib/dfp_api/v201306/team_service.rb,
lib/dfp_api/v201306/user_service.rb,
lib/dfp_api/v201308/team_service.rb,
lib/dfp_api/v201308/user_service.rb,
lib/dfp_api/v201208/label_service.rb,
lib/dfp_api/v201208/order_service.rb,
lib/dfp_api/v201211/label_service.rb,
lib/dfp_api/v201211/order_service.rb,
lib/dfp_api/v201302/label_service.rb,
lib/dfp_api/v201302/order_service.rb,
lib/dfp_api/v201306/label_service.rb,
lib/dfp_api/v201306/order_service.rb,
lib/dfp_api/v201308/label_service.rb,
lib/dfp_api/v201308/order_service.rb,
lib/dfp_api/v201208/report_service.rb,
lib/dfp_api/v201211/report_service.rb,
lib/dfp_api/v201302/report_service.rb,
lib/dfp_api/v201306/report_service.rb,
lib/dfp_api/v201308/report_service.rb,
lib/dfp_api/v201208/company_service.rb,
lib/dfp_api/v201208/content_service.rb,
lib/dfp_api/v201208/network_service.rb,
lib/dfp_api/v201211/company_service.rb,
lib/dfp_api/v201211/content_service.rb,
lib/dfp_api/v201211/network_service.rb,
lib/dfp_api/v201302/ad_rule_service.rb,
lib/dfp_api/v201302/company_service.rb,
lib/dfp_api/v201302/contact_service.rb,
lib/dfp_api/v201302/content_service.rb,
lib/dfp_api/v201302/network_service.rb,
lib/dfp_api/v201306/ad_rule_service.rb,
lib/dfp_api/v201306/company_service.rb,
lib/dfp_api/v201306/contact_service.rb,
lib/dfp_api/v201306/content_service.rb,
lib/dfp_api/v201306/network_service.rb,
lib/dfp_api/v201306/product_service.rb,
lib/dfp_api/v201308/ad_rule_service.rb,
lib/dfp_api/v201308/company_service.rb,
lib/dfp_api/v201308/contact_service.rb,
lib/dfp_api/v201308/content_service.rb,
lib/dfp_api/v201308/network_service.rb,
lib/dfp_api/v201308/product_service.rb,
lib/dfp_api/v201208/creative_service.rb,
lib/dfp_api/v201208/forecast_service.rb,
lib/dfp_api/v201211/creative_service.rb,
lib/dfp_api/v201211/forecast_service.rb,
lib/dfp_api/v201302/activity_service.rb,
lib/dfp_api/v201302/creative_service.rb,
lib/dfp_api/v201302/forecast_service.rb,
lib/dfp_api/v201306/activity_service.rb,
lib/dfp_api/v201306/creative_service.rb,
lib/dfp_api/v201306/forecast_service.rb,
lib/dfp_api/v201306/proposal_service.rb,
lib/dfp_api/v201308/activity_service.rb,
lib/dfp_api/v201308/creative_service.rb,
lib/dfp_api/v201308/forecast_service.rb,
lib/dfp_api/v201308/proposal_service.rb,
lib/dfp_api/v201208/inventory_service.rb,
lib/dfp_api/v201208/line_item_service.rb,
lib/dfp_api/v201208/placement_service.rb,
lib/dfp_api/v201211/inventory_service.rb,
lib/dfp_api/v201211/line_item_service.rb,
lib/dfp_api/v201211/placement_service.rb,
lib/dfp_api/v201302/inventory_service.rb,
lib/dfp_api/v201302/line_item_service.rb,
lib/dfp_api/v201302/placement_service.rb,
lib/dfp_api/v201306/base_rate_service.rb,
lib/dfp_api/v201306/inventory_service.rb,
lib/dfp_api/v201306/line_item_service.rb,
lib/dfp_api/v201306/placement_service.rb,
lib/dfp_api/v201306/rate_card_service.rb,
lib/dfp_api/v201308/base_rate_service.rb,
lib/dfp_api/v201308/inventory_service.rb,
lib/dfp_api/v201308/line_item_service.rb,
lib/dfp_api/v201308/placement_service.rb,
lib/dfp_api/v201308/rate_card_service.rb,
lib/dfp_api/client_login_header_handler.rb,
lib/dfp_api/v201208/creative_set_service.rb,
lib/dfp_api/v201208/custom_field_service.rb,
lib/dfp_api/v201211/creative_set_service.rb,
lib/dfp_api/v201211/custom_field_service.rb,
lib/dfp_api/v201302/creative_set_service.rb,
lib/dfp_api/v201302/custom_field_service.rb,
lib/dfp_api/v201306/creative_set_service.rb,
lib/dfp_api/v201306/custom_field_service.rb,
lib/dfp_api/v201308/creative_set_service.rb,
lib/dfp_api/v201308/custom_field_service.rb,
lib/dfp_api/v201208/team_service_registry.rb,
lib/dfp_api/v201208/user_service_registry.rb,
lib/dfp_api/v201211/team_service_registry.rb,
lib/dfp_api/v201211/user_service_registry.rb,
lib/dfp_api/v201302/team_service_registry.rb,
lib/dfp_api/v201302/user_service_registry.rb,
lib/dfp_api/v201306/team_service_registry.rb,
lib/dfp_api/v201306/user_service_registry.rb,
lib/dfp_api/v201308/team_service_registry.rb,
lib/dfp_api/v201308/user_service_registry.rb,
lib/dfp_api/v201208/label_service_registry.rb,
lib/dfp_api/v201208/order_service_registry.rb,
lib/dfp_api/v201211/label_service_registry.rb,
lib/dfp_api/v201211/order_service_registry.rb,
lib/dfp_api/v201302/activity_group_service.rb,
lib/dfp_api/v201302/content_bundle_service.rb,
lib/dfp_api/v201302/label_service_registry.rb,
lib/dfp_api/v201302/order_service_registry.rb,
lib/dfp_api/v201306/activity_group_service.rb,
lib/dfp_api/v201306/content_bundle_service.rb,
lib/dfp_api/v201306/label_service_registry.rb,
lib/dfp_api/v201306/order_service_registry.rb,
lib/dfp_api/v201308/activity_group_service.rb,
lib/dfp_api/v201308/content_bundle_service.rb,
lib/dfp_api/v201308/label_service_registry.rb,
lib/dfp_api/v201308/order_service_registry.rb,
lib/dfp_api/v201208/report_service_registry.rb,
lib/dfp_api/v201211/report_service_registry.rb,
lib/dfp_api/v201302/report_service_registry.rb,
lib/dfp_api/v201306/report_service_registry.rb,
lib/dfp_api/v201306/workflow_action_service.rb,
lib/dfp_api/v201308/report_service_registry.rb,
lib/dfp_api/v201308/workflow_action_service.rb,
lib/dfp_api/v201208/audience_segment_service.rb,
lib/dfp_api/v201208/company_service_registry.rb,
lib/dfp_api/v201208/content_service_registry.rb,
lib/dfp_api/v201208/custom_targeting_service.rb,
lib/dfp_api/v201208/network_service_registry.rb,
lib/dfp_api/v201208/third_party_slot_service.rb,
lib/dfp_api/v201211/audience_segment_service.rb,
lib/dfp_api/v201211/company_service_registry.rb,
lib/dfp_api/v201211/content_service_registry.rb,
lib/dfp_api/v201211/creative_wrapper_service.rb,
lib/dfp_api/v201211/custom_targeting_service.rb,
lib/dfp_api/v201211/network_service_registry.rb,
lib/dfp_api/v201211/third_party_slot_service.rb,
lib/dfp_api/v201302/ad_rule_service_registry.rb,
lib/dfp_api/v201302/audience_segment_service.rb,
lib/dfp_api/v201302/company_service_registry.rb,
lib/dfp_api/v201302/contact_service_registry.rb,
lib/dfp_api/v201302/content_service_registry.rb,
lib/dfp_api/v201302/creative_wrapper_service.rb,
lib/dfp_api/v201302/custom_targeting_service.rb,
lib/dfp_api/v201302/network_service_registry.rb,
lib/dfp_api/v201302/third_party_slot_service.rb,
lib/dfp_api/v201306/ad_rule_service_registry.rb,
lib/dfp_api/v201306/audience_segment_service.rb,
lib/dfp_api/v201306/company_service_registry.rb,
lib/dfp_api/v201306/contact_service_registry.rb,
lib/dfp_api/v201306/content_service_registry.rb,
lib/dfp_api/v201306/creative_wrapper_service.rb,
lib/dfp_api/v201306/custom_targeting_service.rb,
lib/dfp_api/v201306/network_service_registry.rb,
lib/dfp_api/v201306/product_service_registry.rb,
lib/dfp_api/v201306/product_template_service.rb,
lib/dfp_api/v201308/ad_rule_service_registry.rb,
lib/dfp_api/v201308/audience_segment_service.rb,
lib/dfp_api/v201308/company_service_registry.rb,
lib/dfp_api/v201308/contact_service_registry.rb,
lib/dfp_api/v201308/content_service_registry.rb,
lib/dfp_api/v201308/creative_wrapper_service.rb,
lib/dfp_api/v201308/custom_targeting_service.rb,
lib/dfp_api/v201308/network_service_registry.rb,
lib/dfp_api/v201308/product_service_registry.rb,
lib/dfp_api/v201308/product_template_service.rb,
lib/dfp_api/v201208/creative_service_registry.rb,
lib/dfp_api/v201208/creative_template_service.rb,
lib/dfp_api/v201208/forecast_service_registry.rb,
lib/dfp_api/v201208/suggested_ad_unit_service.rb,
lib/dfp_api/v201211/creative_service_registry.rb,
lib/dfp_api/v201211/creative_template_service.rb,
lib/dfp_api/v201211/forecast_service_registry.rb,
lib/dfp_api/v201211/suggested_ad_unit_service.rb,
lib/dfp_api/v201302/activity_service_registry.rb,
lib/dfp_api/v201302/creative_service_registry.rb,
lib/dfp_api/v201302/creative_template_service.rb,
lib/dfp_api/v201302/forecast_service_registry.rb,
lib/dfp_api/v201302/suggested_ad_unit_service.rb,
lib/dfp_api/v201306/activity_service_registry.rb,
lib/dfp_api/v201306/creative_service_registry.rb,
lib/dfp_api/v201306/creative_template_service.rb,
lib/dfp_api/v201306/forecast_service_registry.rb,
lib/dfp_api/v201306/proposal_service_registry.rb,
lib/dfp_api/v201306/suggested_ad_unit_service.rb,
lib/dfp_api/v201308/activity_service_registry.rb,
lib/dfp_api/v201308/creative_service_registry.rb,
lib/dfp_api/v201308/creative_template_service.rb,
lib/dfp_api/v201308/forecast_service_registry.rb,
lib/dfp_api/v201308/proposal_service_registry.rb,
lib/dfp_api/v201308/suggested_ad_unit_service.rb,
lib/dfp_api/v201208/inventory_service_registry.rb,
lib/dfp_api/v201208/line_item_service_registry.rb,
lib/dfp_api/v201208/placement_service_registry.rb,
lib/dfp_api/v201211/inventory_service_registry.rb,
lib/dfp_api/v201211/line_item_service_registry.rb,
lib/dfp_api/v201211/placement_service_registry.rb,
lib/dfp_api/v201302/inventory_service_registry.rb,
lib/dfp_api/v201302/line_item_service_registry.rb,
lib/dfp_api/v201302/placement_service_registry.rb,
lib/dfp_api/v201306/base_rate_service_registry.rb,
lib/dfp_api/v201306/inventory_service_registry.rb,
lib/dfp_api/v201306/line_item_service_registry.rb,
lib/dfp_api/v201306/line_item_template_service.rb,
lib/dfp_api/v201306/placement_service_registry.rb,
lib/dfp_api/v201306/proposal_line_item_service.rb,
lib/dfp_api/v201306/rate_card_service_registry.rb,
lib/dfp_api/v201308/base_rate_service_registry.rb,
lib/dfp_api/v201308/inventory_service_registry.rb,
lib/dfp_api/v201308/line_item_service_registry.rb,
lib/dfp_api/v201308/line_item_template_service.rb,
lib/dfp_api/v201308/placement_service_registry.rb,
lib/dfp_api/v201308/proposal_line_item_service.rb,
lib/dfp_api/v201308/rate_card_service_registry.rb,
lib/dfp_api/v201208/creative_set_service_registry.rb,
lib/dfp_api/v201208/custom_field_service_registry.rb,
lib/dfp_api/v201208/user_team_association_service.rb,
lib/dfp_api/v201211/creative_set_service_registry.rb,
lib/dfp_api/v201211/custom_field_service_registry.rb,
lib/dfp_api/v201211/user_team_association_service.rb,
lib/dfp_api/v201302/creative_set_service_registry.rb,
lib/dfp_api/v201302/custom_field_service_registry.rb,
lib/dfp_api/v201302/user_team_association_service.rb,
lib/dfp_api/v201306/creative_set_service_registry.rb,
lib/dfp_api/v201306/custom_field_service_registry.rb,
lib/dfp_api/v201306/reconciliation_report_service.rb,
lib/dfp_api/v201306/user_team_association_service.rb,
lib/dfp_api/v201308/creative_set_service_registry.rb,
lib/dfp_api/v201308/custom_field_service_registry.rb,
lib/dfp_api/v201308/reconciliation_report_service.rb,
lib/dfp_api/v201308/user_team_association_service.rb,
lib/dfp_api/v201302/activity_group_service_registry.rb,
lib/dfp_api/v201302/content_bundle_service_registry.rb,
lib/dfp_api/v201306/activity_group_service_registry.rb,
lib/dfp_api/v201306/content_bundle_service_registry.rb,
lib/dfp_api/v201306/rate_card_customization_service.rb,
lib/dfp_api/v201308/activity_group_service_registry.rb,
lib/dfp_api/v201308/content_bundle_service_registry.rb,
lib/dfp_api/v201308/rate_card_customization_service.rb,
lib/dfp_api/v201208/publisher_query_language_service.rb,
lib/dfp_api/v201211/publisher_query_language_service.rb,
lib/dfp_api/v201302/publisher_query_language_service.rb,
lib/dfp_api/v201306/publisher_query_language_service.rb,
lib/dfp_api/v201306/workflow_action_service_registry.rb,
lib/dfp_api/v201308/publisher_query_language_service.rb,
lib/dfp_api/v201308/workflow_action_service_registry.rb,
lib/dfp_api/v201208/audience_segment_service_registry.rb,
lib/dfp_api/v201208/custom_targeting_service_registry.rb,
lib/dfp_api/v201208/third_party_slot_service_registry.rb,
lib/dfp_api/v201211/audience_segment_service_registry.rb,
lib/dfp_api/v201211/creative_wrapper_service_registry.rb,
lib/dfp_api/v201211/custom_targeting_service_registry.rb,
lib/dfp_api/v201211/third_party_slot_service_registry.rb,
lib/dfp_api/v201302/audience_segment_service_registry.rb,
lib/dfp_api/v201302/creative_wrapper_service_registry.rb,
lib/dfp_api/v201302/custom_targeting_service_registry.rb,
lib/dfp_api/v201302/third_party_slot_service_registry.rb,
lib/dfp_api/v201306/audience_segment_service_registry.rb,
lib/dfp_api/v201306/creative_wrapper_service_registry.rb,
lib/dfp_api/v201306/custom_targeting_service_registry.rb,
lib/dfp_api/v201306/product_template_service_registry.rb,
lib/dfp_api/v201306/reconciliation_report_row_service.rb,
lib/dfp_api/v201308/audience_segment_service_registry.rb,
lib/dfp_api/v201308/creative_wrapper_service_registry.rb,
lib/dfp_api/v201308/custom_targeting_service_registry.rb,
lib/dfp_api/v201308/product_template_service_registry.rb,
lib/dfp_api/v201308/reconciliation_report_row_service.rb,
lib/dfp_api/v201208/creative_template_service_registry.rb,
lib/dfp_api/v201208/suggested_ad_unit_service_registry.rb,
lib/dfp_api/v201211/creative_template_service_registry.rb,
lib/dfp_api/v201211/suggested_ad_unit_service_registry.rb,
lib/dfp_api/v201302/creative_template_service_registry.rb,
lib/dfp_api/v201302/suggested_ad_unit_service_registry.rb,
lib/dfp_api/v201306/creative_template_service_registry.rb,
lib/dfp_api/v201306/suggested_ad_unit_service_registry.rb,
lib/dfp_api/v201308/creative_template_service_registry.rb,
lib/dfp_api/v201308/suggested_ad_unit_service_registry.rb,
lib/dfp_api/v201306/line_item_template_service_registry.rb,
lib/dfp_api/v201306/proposal_line_item_service_registry.rb,
lib/dfp_api/v201306/reconciliation_order_report_service.rb,
lib/dfp_api/v201308/line_item_template_service_registry.rb,
lib/dfp_api/v201308/proposal_line_item_service_registry.rb,
lib/dfp_api/v201308/reconciliation_order_report_service.rb,
lib/dfp_api/v201208/line_item_creative_association_service.rb,
lib/dfp_api/v201208/user_team_association_service_registry.rb,
lib/dfp_api/v201211/line_item_creative_association_service.rb,
lib/dfp_api/v201211/user_team_association_service_registry.rb,
lib/dfp_api/v201302/line_item_creative_association_service.rb,
lib/dfp_api/v201302/user_team_association_service_registry.rb,
lib/dfp_api/v201306/line_item_creative_association_service.rb,
lib/dfp_api/v201306/reconciliation_report_service_registry.rb,
lib/dfp_api/v201306/user_team_association_service_registry.rb,
lib/dfp_api/v201308/line_item_creative_association_service.rb,
lib/dfp_api/v201308/reconciliation_report_service_registry.rb,
lib/dfp_api/v201308/user_team_association_service_registry.rb,
lib/dfp_api/v201306/rate_card_customization_service_registry.rb,
lib/dfp_api/v201308/rate_card_customization_service_registry.rb,
lib/dfp_api/v201208/publisher_query_language_service_registry.rb,
lib/dfp_api/v201211/publisher_query_language_service_registry.rb,
lib/dfp_api/v201302/publisher_query_language_service_registry.rb,
lib/dfp_api/v201306/publisher_query_language_service_registry.rb,
lib/dfp_api/v201308/publisher_query_language_service_registry.rb,
lib/dfp_api/v201306/reconciliation_report_row_service_registry.rb,
lib/dfp_api/v201308/reconciliation_report_row_service_registry.rb,
lib/dfp_api/v201306/reconciliation_order_report_service_registry.rb,
lib/dfp_api/v201308/reconciliation_order_report_service_registry.rb,
lib/dfp_api/v201208/line_item_creative_association_service_registry.rb,
lib/dfp_api/v201211/line_item_creative_association_service_registry.rb,
lib/dfp_api/v201302/line_item_creative_association_service_registry.rb,
lib/dfp_api/v201306/line_item_creative_association_service_registry.rb,
lib/dfp_api/v201308/line_item_creative_association_service_registry.rb

Overview

Authors

[email protected] (Danial Klimkin)

Copyright

Copyright 2012, Google Inc. All Rights Reserved.

License

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS,
      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
      implied.
      See the License for the specific language governing permissions and
      limitations under the License.

Module to keep the current library version.

Defined Under Namespace

Modules: ApiConfig, Errors, V201208, V201211, V201302, V201306, V201308 Classes: Api, ClientLoginHeaderHandler, CredentialHandler