Class: DfpApi::Api

Inherits:
AdsCommon::Api
  • Object
show all
Defined in:
lib/dfp_api.rb

Overview

Wrapper class that serves as the main point of access for all the API usage.

Holds all the services, as well as login credentials.

Instance Method Summary collapse

Constructor Details

#initialize(provided_config = nil) ⇒ Api

Constructor for API.



38
39
40
41
# File 'lib/dfp_api.rb', line 38

def initialize(provided_config = nil)
  super(provided_config)
  @credential_handler = DfpApi::CredentialHandler.new(@config)
end

Instance Method Details

#api_config ⇒ Object

Getter for the API service configurations.



44
45
46
# File 'lib/dfp_api.rb', line 44

def api_config
  DfpApi::ApiConfig
end