Class: DfpApi::UtilsReporter
- Inherits:
-
Object
- Object
- DfpApi::UtilsReporter
- Defined in:
- lib/dfp_api/utils_reporter.rb
Instance Method Summary collapse
-
#dfp_date_time_used ⇒ Object
A callback method for DfpDateTime to indicate that it has been used, and that its usage should be recorded in the next user agent string.
-
#dfp_date_used ⇒ Object
A callback method for DfpDate to indicate that it has been used, and that its usage should be recorded in the next user agent string.
-
#initialize(credential_handler) ⇒ UtilsReporter
constructor
Default constructor.
-
#statement_builder_used ⇒ Object
A callback method for StatementBuilder to indicate that it has been used, and that its usage should be recorded in the next user agent string.
Constructor Details
#initialize(credential_handler) ⇒ UtilsReporter
Default constructor.
Args:
- credential_handler: The CredentialHandler being used by the current DfpApi instance.
30 31 32 |
# File 'lib/dfp_api/utils_reporter.rb', line 30 def initialize(credential_handler) @credential_handler = credential_handler end |
Instance Method Details
#dfp_date_time_used ⇒ Object
A callback method for DfpDateTime to indicate that it has been used, and that its usage should be recorded in the next user agent string.
48 49 50 |
# File 'lib/dfp_api/utils_reporter.rb', line 48 def dfp_date_time_used() @credential_handler.include_in_user_agent("DfpDateTime") end |
#dfp_date_used ⇒ Object
A callback method for DfpDate to indicate that it has been used, and that its usage should be recorded in the next user agent string.
42 43 44 |
# File 'lib/dfp_api/utils_reporter.rb', line 42 def dfp_date_used() @credential_handler.include_in_user_agent("DfpDate") end |
#statement_builder_used ⇒ Object
A callback method for StatementBuilder to indicate that it has been used, and that its usage should be recorded in the next user agent string.
36 37 38 |
# File 'lib/dfp_api/utils_reporter.rb', line 36 def statement_builder_used() @credential_handler.include_in_user_agent("StatementBuilder") end |